@@ -1,5 +1,5 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/ExtUtils-Depends/lib/ExtUtils/Depends.pm,v 1.6.2.4 2004/02/12 23:56:21 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/ExtUtils-Depends/lib/ExtUtils/Depends.pm,v 1.10 2004/03/05 05:18:27 muppetman Exp $
 #
 
 package ExtUtils::Depends;
@@ -10,7 +10,14 @@ use Carp;
 use File::Spec;
 use Data::Dumper;
 
-our $VERSION = 0.201;
+our $VERSION = '0.202';
+
+sub import {
+	my $class = shift;
+	return unless @_;
+        die "$class version $_[0] is required--this is only version $VERSION"
+		if $VERSION < $_[0];
+}
 
 sub new {
 	my ($class, $name, @deps) = @_;
@@ -18,7 +25,7 @@ sub new {
 		name => $name,
 		deps => {},
 		inc => [],
-		libs => [],
+		libs => '',
 
 		pm => {},
 		typemaps => [],
